@@ -1459,7 +1459,7 @@ flush(stderr()); flush(stdout())
 ### Name: speccl
 ### Title: A spectral clustering algorithm
 ### Aliases: speccl
-### Keywords: spectral clustering, cluster analysis
+### Keywords: spectral clustering, cluster analysis, scales of measurement
 
 ### ** Examples
 
@@ -1470,12 +1470,13 @@ data<-mlbench.spirals(100,1,0.03)
 plot(data)
 x<-data$x
 res1<-speccl(x,nc=2,distance="GDM1",sigma="automatic",
-mod.sample=0.75,R=10,iterations=3)
+sigma.interval="default",mod.sample=0.75,R=10,iterations=3)
 clas1<-res1$cluster
 print(data$classes)
 print(clas1)
 cRand<-classAgreement(table(as.numeric(as.vector(data$classes)),
-res1$cluster))$crand
+res1$clusters))$crand
+print(res1$sigma)
 print(cRand)
 
 # Example 2
@@ -1485,9 +1486,11 @@ data<-as.matrix(grnd2$data)
 colornames<-c("red","blue","green")
 grnd2$clusters[grnd2$clusters==0]<-length(colornames)
 plot(grnd2$data,col=colornames[grnd2$clusters])
+us<-nrow(data)*nrow(data)/2
 res2<-speccl(data,nc=3,distance="sEuclidean",sigma="automatic",
-mod.sample=0.75,R=10,iterations=3)
-cRand<-comparing.Partitions(grnd2$clusters,res2$cluster,type="crand")
+sigma.interval=us,mod.sample=0.75,R=10,iterations=3)
+cRand<-comparing.Partitions(grnd2$clusters,res2$clusters,type="crand")
+print(res2$sigma)
 print(cRand)
 
 # Example 3
@@ -1497,24 +1500,18 @@ data<-as.matrix(grnd3$data)
 plotCategorial(grnd3$data,pairsofVar=NULL,cl=grnd3$clusters,
 clColors=c("red","blue","green"))
 res3<-speccl(data,nc=3,distance="GDM2",sigma="automatic",
-mod.sample=0.75,R=10,iterations=3)
-cRand<-comparing.Partitions(grnd3$clusters,res3$cluster,type="crand")
+sigma.interval="default",mod.sample=0.75,R=10,iterations=3)
+cRand<-comparing.Partitions(grnd3$clusters,res3$clusters,type="crand")
+print(res3$sigma)
 print(cRand)
 
 # Example 4
 library(clusterSim)
 data(data_nominal)
 res4<-speccl(data_nominal,nc=4,distance="SM",sigma="automatic",
-mod.sample=0.75,R=10,iterations=3)
+sigma.interval="default",mod.sample=0.75,R=10,iterations=3)
 print(res4)
 
-# Example 5
-library(clusterSim)
-data(data_binary)
-res5<-speccl(data_binary,nc=3,distance=1,sigma="automatic",
-mod.sample=0.75,R=10,iterations=3)
-print(res5)
-
 
 
 
